"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.space = exports.semibold = exports.regular = exports.radius = exports.radii = exports.mediaQueries = exports.maxContainerWidth = exports.light = exports.fonts = exports.fontWeights = exports.fontSizes = exports.fontFamily = exports["default"] = exports.colors = exports.breakpoints = exports.bold = void 0;
var _polished = require("polished");
// import { createGlobalStyle } from 'styled-components'

// export const GlobalStyles = createGlobalStyle`
//   * {
//     -webkit-font-smoothing: antialiased;
//     box-sizing: border-box;
//     text-size-adjust: 100%;
//   }
//   body {
//     margin: 0;
//   }
// `
var createMediaQuery = function createMediaQuery(n) {
  return "@media screen and (min-width:".concat(n, ")");
};
var addAliases = function addAliases(arr, aliases) {
  return aliases.forEach(function (key, i) {
    return Object.defineProperty(arr, key, {
      enumerable: false,
      get: function get() {
        return this[i];
      }
    });
  });
};
var breakpoints = ['640px', '768px', '1024px', '1200px'];
exports.breakpoints = breakpoints;
var mediaQueries = breakpoints.map(createMediaQuery);
exports.mediaQueries = mediaQueries;
var aliases = ['sm', 'md', 'lg', 'xl'];
addAliases(breakpoints, aliases);
addAliases(mediaQueries, aliases);

//                    0  1  2   3   4   5    6
var space = [0, 4, 8, 16, 32, 80, 150];

// https://bitsofco.de/the-new-system-font-stack/
exports.space = space;
var fontFamily = "-apple-system, BlinkMacSystemFont, \"Segoe UI\", Roboto, Oxygen-Sans, Ubuntu, Cantarell, \"Helvetica Neue\", sans-serif";
exports.fontFamily = fontFamily;
var fonts = {
  sans: fontFamily
};

//                        0    1   2   3   4   5    6
exports.fonts = fonts;
var fontSizes = [12, 14, 16, 18, 24, 32, 48].map(function (px) {
  return "".concat(px / 16, "rem");
});
exports.fontSizes = fontSizes;
var light = 400;
exports.light = light;
var regular = 400;
exports.regular = regular;
var semibold = 500;
exports.semibold = semibold;
var bold = 600;

// styled-system's `fontWeight` function can hook into the `fontWeights` object
exports.bold = bold;
var fontWeights = {
  light: light,
  regular: regular,
  semibold: semibold,
  bold: bold
};

// color palette
exports.fontWeights = fontWeights;
var black = '#000';
var white = '#fff';
var blue = 'blue';
var text = '#001833';
var sidebarblue = '#F5F7F9';
var footerlightblue = (0, _polished.transparentize)(0.5, sidebarblue);
// TODO okay to use transparency? or should mix with white?

var aqua = '#3A8BBB'; // primary colour for buttons/links

// footer text
var bluegray = '#637281';
var darkbluegray = '#4B5158';

// 6 shades of gray
var graytext = '#464646';
var grayapptitle = '#585858';
var graylabeltext = '#696969';
var grayheading = '#747474';
var graybuttonborder = '#CCCCCC';
var lightgreyborder = '#F0F0F0';
var errorlabelred = '#dd2c00';
var labelplaceholder = 'rgba(0,0,0,.54)';
var inputborder = 'rgba(0,0,0,0.12)';
var inputfocusbc = '#F9F9F9';
var inputinvalidbc = 'hsla(0, 100%, 97%, 1)';
var colors = {
  black: black,
  white: white,
  blue: blue,
  text: text,
  aqua: aqua,
  bluegray: bluegray,
  darkbluegray: darkbluegray,
  sidebarblue: sidebarblue,
  footerlightblue: footerlightblue,
  graytext: graytext,
  grayapptitle: grayapptitle,
  graylabeltext: graylabeltext,
  grayheading: grayheading,
  graybuttonborder: graybuttonborder,
  lightgreyborder: lightgreyborder,
  labelplaceholder: labelplaceholder,
  errorlabelred: errorlabelred,
  inputborder: inputborder,
  inputfocusbc: inputfocusbc,
  inputinvalidbc: inputinvalidbc
};
exports.colors = colors;
//
// const buttons = {
//   primary: {
//     color: 'white',
//     backgroundColor: buttonblue,
//     '&:hover': {
//       backgroundColor: darken(0.1, buttonblue),
//     }
//   }
// }

// styled-system's `borderRadius` function can hook into the `radii` object/array
var radii = [0, 2, 4];
exports.radii = radii;
var radius = '2px';
exports.radius = radius;
var maxContainerWidth = '1280px';
exports.maxContainerWidth = maxContainerWidth;
var theme = {
  breakpoints: breakpoints,
  mediaQueries: mediaQueries,
  space: space,
  fonts: fonts,
  fontFamily: fontFamily,
  fontSizes: fontSizes,
  fontWeights: fontWeights,
  regular: regular,
  bold: bold,
  colors: colors,
  radii: radii,
  radius: radius,
  maxContainerWidth: maxContainerWidth
};
var _default = theme;
exports["default"] = _default;